@@ -11,8 +11,8 @@ def communicationInitialization(port, baudrate):
     communication.init_serial(port, baudrate)
 
 
-def executeCommand(pump, command):
-    communication.send_command(pump.asciiAddress, command)
+def executeCommand(pump, command, waitForPump=False):
+    communication.send_command(pump.asciiAddress, command, waitForPump)
 
 
 def definePump(address: str, type=4, baudRate=9600, resolutionMode=0):
