@@ -9,9 +9,9 @@ class PSD:
     # standard resolution has value 0 = 3000 steps
     resolutionMode = 0
     # type of PSD: 4 / 6 / 4sf / 6sf, most used is psd4
-    type = 4
+    type = util.PSDTypes.psd4
 
-    def __init__(self, address: str, type=4, baudRate=9600, resolutionMode=0):
+    def __init__(self, address: str, type: util.PSDTypes, baudRate=9600, resolutionMode=0):
         self.setAddress(address)
         self.type = type
         self.baudRate = baudRate
